@@ -5,12 +5,12 @@ FastAPI-based REST API for WhiteMagic memory management.
 Provides authenticated access to memory operations, search, and context generation.
 """
 
-__version__ = "2.1.0"
+__version__ = "2.2.8"
 
 from .app import app
-from .database import Database, User, APIKey, Quota
 from .auth import create_api_key, validate_api_key
-from .rate_limit import RateLimiter, PLAN_LIMITS
+from .database import APIKey, Database, Quota, User
+from .rate_limit import PLAN_LIMITS, RateLimiter
 
 __all__ = [
     "__version__",
