@@ -4,21 +4,21 @@ WhiteMagic API - FastAPI Application
 REST API for WhiteMagic memory management system.
 """
 
-import os
 import asyncio
+import os
+from contextlib import asynccontextmanager
+from datetime import datetime
+from functools import lru_cache
 from pathlib import Path
 from typing import Optional
-from contextlib import asynccontextmanager
-from functools import lru_cache
 
-from datetime import datetime
-from fastapi import FastAPI, HTTPException, status, Depends
+from fastapi import FastAPI, HTTPException
 from fastapi.middleware.cors import CORSMiddleware
-from fastapi.responses import JSONResponse, FileResponse
+from fastapi.responses import FileResponse, JSONResponse
 from fastapi.staticfiles import StaticFiles
 
 # Setup logging first
-from .structured_logging import setup_logging, get_logger
+from .structured_logging import get_logger, setup_logging
 
 # Configure logging
 log_level = os.getenv("LOG_LEVEL", "INFO")
@@ -27,43 +27,42 @@ setup_logging(level=log_level, json_logs=json_logs)
 
 logger = get_logger(__name__)
 
-from .database import Database, User
-from .dependencies import set_database, CurrentUser, DBSession
+from .database import Database
+from .dependencies import CurrentUser, DBSession, set_database
 from .memory_service import get_memory_manager
-from .version import get_version, get_version_dict
-from .rate_limit import (
-    RateLimiter,
-    set_rate_limiter,
-    get_rate_limiter,
-    refresh_quota_usage,
-)
 from .middleware import (
     AuthMiddleware,
-    RequestLoggingMiddleware,
     CORSHeadersMiddleware,
     RateLimitMiddleware,
+    RequestLoggingMiddleware,
 )
 from .models import (
+    ConsolidateRequest,
+    ConsolidateResponse,
+    ContextRequest,
+    ContextResponse,
     CreateMemoryRequest,
-    UpdateMemoryRequest,
-    MemoryResponse,
+    ErrorDetail,
+    ErrorResponse,
     MemoryListResponse,
+    MemoryResponse,
     SearchRequest,
     SearchResponse,
     SearchResultItem,
-    ContextRequest,
-    ContextResponse,
-    ConsolidateRequest,
-    ConsolidateResponse,
     StatsResponse,
-    TagsResponse,
-    UserResponse,
-    UserInfo,
-    UsageStats,
-    ErrorResponse,
-    ErrorDetail,
     SuccessResponse,
+    TagsResponse,
+    UpdateMemoryRequest,
+    UsageStats,
+    UserInfo,
+    UserResponse,
 )
+from .rate_limit import (
+    RateLimiter,
+    refresh_quota_usage,
+    set_rate_limiter,
+)
+from .version import get_version, get_version_dict
 
 
 @asynccontextmanager
@@ -71,7 +70,7 @@ async def lifespan(app: FastAPI):
     """Lifespan context manager for startup/shutdown."""
     # Startup
     logger.info("whitemagic_startup", extra={"version": get_version()})
-    
+
     database_url = os.getenv(
         "DATABASE_URL", "sqlite+aiosqlite:///./whitemagic.db"  # Default for development
     )
@@ -79,7 +78,9 @@ async def lifespan(app: FastAPI):
     db = Database(database_url, echo=False)
     await db.create_tables()
     set_database(db)
-    logger.info("database_initialized", extra={"url": database_url.split("@")[-1]})  # Hide credentials
+    logger.info(
+        "database_initialized", extra={"url": database_url.split("@")[-1]}
+    )  # Hide credentials
 
     # Initialize rate limiter
     redis_url = os.getenv("REDIS_URL")
@@ -121,6 +122,7 @@ app.add_middleware(RequestLoggingMiddleware)  # Runs 3rd (logs with user context
 app.add_middleware(RateLimitMiddleware)  # Runs 2nd (enforces limits with user)
 app.add_middleware(AuthMiddleware)  # Runs 1st (sets request.state.user)
 
+
 # Optional Sentry integration
 @lru_cache(maxsize=1)
 def _maybe_init_sentry() -> None:
@@ -151,18 +153,19 @@ _maybe_init_sentry()
 # Health & System Endpoints
 # ============================================================================
 
+
 @app.get("/health", tags=["System"])
 async def health_check():
     """
     Health check endpoint (liveness probe).
-    
+
     Returns 200 if the service is running.
     Does not check external dependencies.
     """
     return {
         "status": "healthy",
         "version": get_version(),
-        "timestamp": datetime.utcnow().isoformat() + "Z"
+        "timestamp": datetime.utcnow().isoformat() + "Z",
     }
 
 
@@ -170,30 +173,28 @@ async def health_check():
 async def readiness_check(db: DBSession):
     """
     Readiness check endpoint (readiness probe).
-    
+
     Returns 200 if the service can handle requests.
     Checks database connectivity.
     """
     try:
         from sqlalchemy import text
+
         await db.execute(text("SELECT 1"))
         return {
             "status": "ready",
             "version": get_version(),
-            "timestamp": datetime.utcnow().isoformat() + "Z"
+            "timestamp": datetime.utcnow().isoformat() + "Z",
         }
     except Exception as e:
-        raise HTTPException(
-            status_code=503,
-            detail=f"Service not ready: {str(e)}"
-        )
+        raise HTTPException(status_code=503, detail=f"Service not ready: {str(e)}")
 
 
 @app.get("/openapi.json", include_in_schema=False)
 async def get_openapi_schema():
     """
     Get frozen OpenAPI v1 schema.
-    
+
     This endpoint returns the complete API schema.
     Clients can use this for code generation.
     """
@@ -259,10 +260,7 @@ async def general_exception_handler(request, exc: Exception):
     logger.error(
         "unexpected_error",
         exc_info=True,
-        extra={
-            "method": request.method,
-            "path": request.url.path
-        }
+        extra={"method": request.method, "path": request.url.path},
     )
 
     return JSONResponse(
@@ -293,7 +291,7 @@ if dashboard_dir.exists():
 
 
 # Include routes
-from .routes import dashboard, search, api_keys
+from .routes import api_keys, dashboard, search
 
 app.include_router(dashboard.router)
 app.include_router(search.router, prefix="/api/v1")
@@ -310,16 +308,16 @@ if EXEC_API_ENABLED:
             "enabled": True,
             "default_profile": "PROD",
             "security_warning": "Terminal execution API is ENABLED. Only enable in controlled environments!",
-            "disable_with": "WM_ENABLE_EXEC_API=false"
-        }
+            "disable_with": "WM_ENABLE_EXEC_API=false",
+        },
     )
 else:
     logger.info(
         "terminal_exec_api_disabled",
         extra={
-            "enabled": False, 
+            "enabled": False,
             "enable_with": "WM_ENABLE_EXEC_API=true",
-            "security_note": "Terminal execution API is DISABLED by default for security. Enable only if needed."
+            "security_note": "Terminal execution API is DISABLED by default for security. Enable only if needed.",
         },
     )
 
@@ -370,11 +368,13 @@ async def create_memory(
 async def list_memories(
     user: CurrentUser,
     type: Optional[str] = None,
+    include_archived: bool = False,
 ):
     """
     List all memories for the current user.
 
-    Optionally filter by type (short_term or long_term).
+    Optionally filter by type (short_term, long_term, or archive).
+    Set include_archived=true to include archived memories in results.
     """
     try:
         manager = get_memory_manager(user)
@@ -384,8 +384,10 @@ async def list_memories(
         if type:
             memories = all_memories.get(type, [])
         else:
-            # Combine all types
+            # Combine active types (and archive if requested)
             memories = all_memories.get("short_term", []) + all_memories.get("long_term", [])
+            if include_archived:
+                memories += all_memories.get("archive", [])
 
         memory_responses = [_memory_response(manager, m) for m in memories]
 
@@ -463,19 +465,48 @@ async def delete_memory(
     filename: str,
     user: CurrentUser,
     session: DBSession,
+    permanent: bool = False,
 ):
-    """Delete a memory."""
+    """
+    Delete a memory.
+
+    By default, memories are archived (soft delete).
+    Set permanent=true for permanent deletion (cannot be restored).
+    """
     try:
         manager = get_memory_manager(user)
-        await asyncio.to_thread(manager.delete_memory, filename)
+        await asyncio.to_thread(manager.delete_memory, filename, permanent=permanent)
         await refresh_quota_usage(session, user, manager)
 
-        return SuccessResponse(message=f"Memory deleted: {filename}")
+        action = "permanently deleted" if permanent else "archived"
+        return SuccessResponse(message=f"Memory {action}: {filename}")
 
     except Exception as e:
         raise HTTPException(500, f"Failed to delete memory: {str(e)}")
 
 
+@app.post("/api/v1/memories/{filename}/restore", response_model=SuccessResponse, tags=["Memories"])
+async def restore_memory(
+    filename: str,
+    user: CurrentUser,
+    session: DBSession,
+):
+    """
+    Restore an archived memory.
+
+    Moves the memory from archive back to its original type (short_term or long_term).
+    """
+    try:
+        manager = get_memory_manager(user)
+        await asyncio.to_thread(manager.restore_memory, filename)
+        await refresh_quota_usage(session, user, manager)
+
+        return SuccessResponse(message=f"Memory restored: {filename}")
+
+    except Exception as e:
+        raise HTTPException(500, f"Failed to restore memory: {str(e)}")
+
+
 # Search endpoint
 
 
@@ -497,11 +528,12 @@ async def search_memories(
             query=request.query,
             tags=request.tags,
             memory_type=request.type,
+            include_archived=request.include_archived,
         )
-        
+
         # Apply limit after search
         if request.limit:
-            results = results[:request.limit]
+            results = results[: request.limit]
 
         search_results = [
             SearchResultItem(
@@ -665,9 +697,10 @@ async def get_current_user_info(
     """Get current user information and usage stats."""
     try:
         # Get quota from database
-        from .database import Quota
         from sqlalchemy import select
 
+        from .database import Quota
+
         result = await session.execute(select(Quota).where(Quota.user_id == user.id))
         quota = result.scalar_one_or_none()
 
