@@ -1,5 +1,5 @@
 """WhiteMagic API Routes."""
 
-from . import dashboard, api_keys
+from . import api_keys, dashboard
 
 __all__ = ["dashboard", "api_keys"]
