@@ -8,66 +8,48 @@ Refactored from the original memory_manager.py to be importable as a Python pack
 from __future__ import annotations
 
 import json
-import re
 from datetime import datetime, timedelta
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple, Any, Sequence
-
-from .fileio import file_lock, atomic_write
+from typing import Any, Dict, List, Optional, Sequence, Tuple
 
 from .constants import (
-    DEFAULT_MEMORY_DIR,
-    DEFAULT_SHORT_TERM_DIR,
-    DEFAULT_LONG_TERM_DIR,
-    DEFAULT_ARCHIVE_DIR,
-    DEFAULT_METADATA_FILE,
-    DEFAULT_SHORT_TERM_RETENTION_DAYS,
-    DEFAULT_CONSOLIDATION_THRESHOLD,
-    DEFAULT_NORMALIZE_TAGS,
     AUTO_PROMOTION_TAGS,
-    TIER_CONTEXT_RULES,
-    MEMORY_TYPE_SHORT_TERM,
+    DEFAULT_ARCHIVE_DIR,
+    DEFAULT_CONSOLIDATION_THRESHOLD,
+    DEFAULT_LONG_TERM_DIR,
+    DEFAULT_METADATA_FILE,
+    DEFAULT_NORMALIZE_TAGS,
+    DEFAULT_SHORT_TERM_DIR,
+    DEFAULT_SHORT_TERM_RETENTION_DAYS,
+    MEMORY_FILE_EXTENSION,
     MEMORY_TYPE_LONG_TERM,
-    VALID_MEMORY_TYPES,
-    STATUS_ACTIVE,
-    STATUS_ARCHIVED,
+    MEMORY_TYPE_SHORT_TERM,
+    SORT_BY_ACCESSED,
     SORT_BY_CREATED,
     SORT_BY_UPDATED,
-    SORT_BY_ACCESSED,
+    STATUS_ACTIVE,
+    STATUS_ARCHIVED,
+    TIER_CONTEXT_RULES,
+    VALID_MEMORY_TYPES,
     VALID_SORT_OPTIONS,
-    MEMORY_FILE_EXTENSION,
 )
 from .exceptions import (
-    MemoryNotFoundError,
     InvalidMemoryTypeError,
     InvalidSortOptionError,
     InvalidTierError,
-    MemoryAlreadyArchivedError,
-    MemoryNotArchivedError,
-    FileOperationError,
-)
-from .models import (
-    Memory,
-    MemoryCreate,
-    MemoryUpdate,
-    MemorySearchQuery,
-    ContextRequest,
-    ConsolidateRequest,
-    RestoreRequest,
-    NormalizeTagsRequest,
 )
+from .fileio import atomic_write, file_lock
 from .utils import (
-    now_iso,
-    slugify,
-    normalize_tags,
     clean_markdown,
-    truncate_text,
-    summarize_text,
-    create_preview,
-    split_frontmatter,
-    parse_frontmatter,
     create_frontmatter,
+    create_preview,
+    normalize_tags,
+    now_iso,
     parse_datetime,
+    slugify,
+    split_frontmatter,
+    summarize_text,
+    truncate_text,
 )
 
 
@@ -615,12 +597,13 @@ class MemoryManager:
     # Context Generation
     # ------------------------------------------------------------------ #
 
-    def generate_context_summary(self, tier: int) -> str:
+    def generate_context_summary(self, tier: int, role: Optional[str] = None) -> str:
         """
         Generate a context summary for a given tier.
 
         Args:
             tier: Context tier (0, 1, or 2)
+            role: Optional task role for smart preloading (e.g., "bug-fix", "feature")
 
         Returns:
             Formatted context string
@@ -633,7 +616,23 @@ class MemoryManager:
 
         rules = self.TIER_CONTEXT_RULES[tier]
         sections = []
-        sections.append(f"## Context Package (Tier {tier})\n")
+
+        # Add role info if provided
+        if role:
+            sections.append(f"## Context Package (Tier {tier}, Role: {role})\n")
+            # Preload relevant memories for this role
+            try:
+                from whitemagic.context_preload import preload_for_role
+
+                preloaded = preload_for_role(role, max_memories=5)
+                if preloaded:
+                    sections.append(
+                        f"*Preloaded {len(preloaded)} relevant memories for {role} role*\n"
+                    )
+            except Exception:
+                pass  # Graceful degradation if preloading fails
+        else:
+            sections.append(f"## Context Package (Tier {tier})\n")
 
         for memory_type, heading in [
             (MEMORY_TYPE_SHORT_TERM, "Short-Term Memories"),
@@ -725,7 +724,9 @@ class MemoryManager:
         retention_days = (
             min_age_days
             if min_age_days is not None
-            else int(self.metadata.get("short_term_retention_days", DEFAULT_SHORT_TERM_RETENTION_DAYS))
+            else int(
+                self.metadata.get("short_term_retention_days", DEFAULT_SHORT_TERM_RETENTION_DAYS)
+            )
         )
         cutoff = datetime.now() - timedelta(days=retention_days)
         promotion_tags = {tag.lower() for tag in (auto_promote_tags or self.PROMOTION_TAGS)}
@@ -844,9 +845,7 @@ class MemoryManager:
             self._save_metadata()
 
         archived_files = (
-            archive_targets
-            if not dry_run
-            else [item["entry"]["filename"] for item in old_entries]
+            archive_targets if not dry_run else [item["entry"]["filename"] for item in old_entries]
         )
 
         return {
@@ -1191,13 +1190,13 @@ class MemoryManager:
             if e.get("filename") == filename:
                 entry = e
                 break
-        
+
         if not entry:
             raise FileNotFoundError(f"Memory not found: {filename}")
-        
+
         # Read full content
         frontmatter, body = self._read_memory_file(entry)
-        
+
         if include_metadata:
             return {
                 "filename": entry.get("filename"),
