@@ -13,18 +13,8 @@ Example usage:
     ... )
 """
 
-from .semantic import (
-    semantic_search,
-    SemanticSearcher,
-    SearchMode,
-    SearchResult
-)
+from .semantic import SearchMode, SearchResult, SemanticSearcher, semantic_search
 
-__all__ = [
-    "semantic_search",
-    "SemanticSearcher", 
-    "SearchMode",
-    "SearchResult"
-]
+__all__ = ["semantic_search", "SemanticSearcher", "SearchMode", "SearchResult"]
 
-__version__ = "0.1.0"
+__version__ = "2.2.8"
