@@ -1,9 +1,9 @@
 """WhiteMagic Terminal Tool - Structured execution for agents."""
 
-from .executor import Executor, ExecutionResult
 from .allowlist import Allowlist, Profile
-from .audit import AuditLogger, AuditLog
-from .mcp_tools import TerminalMCPTools, TOOLS
+from .audit import AuditLog, AuditLogger
+from .executor import ExecutionResult, Executor
+from .mcp_tools import TOOLS, TerminalMCPTools
 from .models import ExecutionMode, ExecutionRequest, ExecutionResponse
 
 __all__ = [
@@ -20,4 +20,4 @@ __all__ = [
     "ExecutionResponse",
 ]
 
-__version__ = "0.1.0"
+__version__ = "2.2.8"
