@@ -4,7 +4,7 @@ WhiteMagic utility functions.
 
 import re
 from datetime import datetime
-from typing import List, Tuple, Dict, Any
+from typing import Any, Dict, List, Tuple
 
 
 def now_iso() -> str:
@@ -174,10 +174,11 @@ def parse_frontmatter(block: str) -> Dict[str, Any]:
     """
     Parse YAML-style frontmatter block.
 
-    Simple parser that handles:
+    Uses PyYAML for proper parsing of YAML structures including:
     - key: value
     - key: [item1, item2]
-    - tags: tag1, tag2
+    - Multi-line lists
+    - Nested structures
 
     Args:
         block: Frontmatter block text
@@ -185,39 +186,14 @@ def parse_frontmatter(block: str) -> Dict[str, Any]:
     Returns:
         Dictionary of parsed values
     """
-    data: Dict[str, Any] = {}
-    for line in block.splitlines():
-        stripped = line.strip()
-        if not stripped or stripped.startswith("#"):
-            continue
+    import yaml
 
-        if ":" in stripped:
-            key, value = stripped.split(":", 1)
-            key = key.strip()
-            value = value.strip()
-
-            # Parse lists
-            if value.startswith("[") and value.endswith("]"):
-                items = value[1:-1].split(",")
-                data[key] = [item.strip().strip("'\"") for item in items if item.strip()]
-            # Parse comma-separated (for tags) or single tag
-            elif key == "tags":
-                if "," in value:
-                    data[key] = [item.strip() for item in value.split(",") if item.strip()]
-                else:
-                    # Single tag - still return as list
-                    data[key] = [value.strip()] if value.strip() else []
-            # Parse booleans
-            elif value.lower() in ("true", "false"):
-                data[key] = value.lower() == "true"
-            # Parse numbers
-            elif value.isdigit():
-                data[key] = int(value)
-            # String value
-            else:
-                data[key] = value.strip("'\"")
-
-    return data
+    try:
+        data = yaml.safe_load(block)
+        return data if isinstance(data, dict) else {}
+    except yaml.YAMLError:
+        # Fallback to empty dict if YAML is invalid
+        return {}
 
 
 def create_frontmatter(
@@ -243,8 +219,12 @@ def create_frontmatter(
     lines.append(f"created: {timestamp.isoformat(timespec='seconds')}Z")
 
     if tags:
-        tags_str = ", ".join(tags)
-        lines.append(f"tags: {tags_str}")
+        # Write as YAML list format for proper parsing
+        if len(tags) == 1:
+            lines.append(f"tags: [{tags[0]}]")
+        else:
+            tags_str = ", ".join(tags)
+            lines.append(f"tags: [{tags_str}]")
 
     if extra_fields:
         for key, value in extra_fields.items():
@@ -264,17 +244,20 @@ def create_frontmatter(
 def serialize_frontmatter(frontmatter: Dict[str, Any], body: str) -> str:
     """
     Serialize a frontmatter dictionary and body back into a markdown file.
-    
+
     Args:
         frontmatter: Dictionary of frontmatter fields
         body: Markdown body content
-    
+
     Returns:
         Complete markdown file content with frontmatter and body
     """
     import yaml
+
     lines = ["---"]
-    yaml_content = yaml.dump(frontmatter, default_flow_style=False, allow_unicode=True, sort_keys=False)
+    yaml_content = yaml.dump(
+        frontmatter, default_flow_style=False, allow_unicode=True, sort_keys=False
+    )
     lines.append(yaml_content.rstrip())
     lines.append("---")
     lines.append("")
